@@ -1,6 +1,8 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from typing import Any, Dict, Optional
+from __future__ import annotations
+
+from typing import Any
 from ocp_resources.resource import NamespacedResource, MissingRequiredArgumentError
 
 
@@ -13,12 +15,12 @@ class ServiceMeshMember(NamespacedResource):
 
     def __init__(
         self,
-        control_plane_ref: Optional[Dict[str, Any]] = None,
+        control_plane_ref: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
         """
         Args:
-            control_plane_ref (Dict[str, Any]): No field description from API; please add description
+            control_plane_ref (dict[str, Any]): No field description from API; please add description
 
         """
         super().__init__(**kwargs)
@@ -28,11 +30,9 @@ class ServiceMeshMember(NamespacedResource):
     def to_dict(self) -> None:
         super().to_dict()
 
-        if not self.yaml_file:
-            if not all([
-                self.control_plane_ref,
-            ]):
-                raise MissingRequiredArgumentError(argument="control_plane_ref")
+        if not self.kind_dict and not self.yaml_file:
+            if self.control_plane_ref is None:
+                raise MissingRequiredArgumentError(argument="self.control_plane_ref")
 
             self.res["spec"] = {}
             _spec = self.res["spec"]
